@@ -1,16 +1,18 @@
 """
-[main]
+[notion_oauth_handler]
 consumer = dummy
 auth_view = default
 custom_section = my_application
 
-[server]
+[notion_oauth_handler.server]
 base_path =
 redirect_path = /auth_redirect
 
-[notion]
+[notion_oauth_handler.notion]
 client_id = ...
+# or notion_client_id_key = ...
 client_secret = ...
+# or notion_client_secret_key = ...
 
 [my_application]
 # Your custom application settings go here
@@ -20,6 +22,8 @@ import configparser
 
 import attr
 
+import notion_oauth_handler as package
+
 
 @attr.s(frozen=True)
 class AppConfiguration:
@@ -37,21 +41,25 @@ class AppConfiguration:
 def load_config_from_file(filename: str) -> AppConfiguration:
     config = configparser.ConfigParser()
     config.read(filename)
+    package_name = package.__name__
 
-    custom_settings = {}
-    main_section = config['main']
+    custom_settings: dict[str, str] = {}
+    main_section = config[package_name]
     if main_section.get('custom_section'):
         custom_section_name = main_section['custom_section']
-        custom_settings = config[custom_section_name]
+        custom_settings = dict(config[custom_section_name])
+
+    notion_section = config[f'{package_name}.notion']
+    server_section = config[f'{package_name}.server']
 
     return AppConfiguration(
         consumer_name=main_section.get('consumer', 'dummy'),
         auth_view_name=main_section.get('auth_view', 'default'),
-        notion_client_id=config['notion'].get('client_id', ''),
-        notion_client_id_key=config['notion'].get('client_id_key', ''),
-        notion_client_secret=config['notion'].get('client_secret', ''),
-        notion_client_secret_key=config['notion'].get('client_secret_key', ''),
-        base_path=config['server'].get('base_path', ''),
-        redirect_path=config['server'].get('redirect_path', '/auth_redirect'),
+        notion_client_id=notion_section.get('client_id', ''),
+        notion_client_id_key=notion_section.get('client_id_key', ''),
+        notion_client_secret=notion_section.get('client_secret', ''),
+        notion_client_secret_key=notion_section.get('client_secret_key', ''),
+        base_path=server_section.get('base_path', ''),
+        redirect_path=server_section.get('redirect_path', '/auth_redirect'),
         custom_settings=custom_settings,
     )
